<?php


class JWP6_Admin_Page_Licensing extends JWP6_Admin_Page {

    public function __construct() {

        parent::__construct();
        $license_version_field =  new JWP6_Form_Field_Select(
            'license_version',
            array(
				'label' => 'نسخه مجوز',
                'options' => JWP6_Plugin::$license_versions,
                'default' => 'free',
                'description_is_value' => true,
                'help_text' => 'نسخه ای از پخش کننده را که می خواهید ار آن استفاده کنید و تنظیمات اضافی پوسته را باز می کند و واترمارک را بر می دارد، انتخاب کنید.',
            )
        );
        $license_key_field = new JWP6_Form_Field(
            'license_key', 
            array(
				'label' => 'کلید مجوز',
                'validation' => array($this, "license_key_validation"),
                'help_text' => 'یک کلید مجور برای نسخه های حرفه ای، ویزه و تبلیغات مورد نیاز است.',
            )
        );

        if ( JWP6_USE_CUSTOM_SHORTCODE_FILTER ) {
            $default_config_options = array(
                'label' => 'برگه های دسته بندی',
                'options' => array(
                    'excerpt' => 'استفاده از چکیده',
                    'content' => 'استفاده از محتوا',
                    'disable' => 'نوار شرت کد',
                ),
                'default' => 'content',
                'single_line' => true,
            );

            $category_config_options = $default_config_options;
            $category_config_options['label'] = 'برگه های دسته بندی';
            $category_config_field = new JWP6_Form_Field_Radio(
                'category_config',
                $category_config_options
            );        

            $search_config_options = $default_config_options;
            $search_config_options['label'] = 'برگه های جستجو';
            $search_config_field = new JWP6_Form_Field_Radio(
                'search_config',
                $search_config_options
            );        

            $tag_config_options = $default_config_options;
            $tag_config_options['label'] = 'برگه های برچسب';
            $tag_config_field = new JWP6_Form_Field_Radio(
                'tag_config',
                $tag_config_options
            );        

            $home_config_options = $default_config_options;
            $home_config_options['label'] = 'برگه اصلی';
            $home_config_field = new JWP6_Form_Field_Radio(
                'home_config',
                $home_config_options
            );        
        }

        $tracking_field = new JWP6_Form_Field_Toggle(
            'allow_anonymous_tracking',
            array(
                'label' => 'ردیابی ناشناس',
                'text' => 'اجازه ردیابی ناشناس ویژگی هایی که افزونه استفاده می کند.',
                'help_text' => 'ما ویژگی های کلی (نسخه پخش کننده، آدرس های خارجی، لیست های پخش و ...) را که شما استفاده می کنید، ردیابی می کنیم. این به ما کمک خواهد کرد که ویزگی های افزونه را در آینده بهبود ببخشیم.',
                'default' => true,
            )
        );
        
        $purge_field = new JWP6_Form_Field_Toggle(
            'purge_settings_at_deactivation',
            array(
                'label' => 'تنظیمات پاکسازی',
                'text' => 'تمام تنظیمات را هنگامی که من افزونه را غیرفعال کردم پاکسازی کن.',
                'default' => false,
                'help_text' => 'توجه داشته باشید که این فرایند برگشت ناپذیر است. اگر تاکنون تصمیم گرفته اید که افزونه را دوباره فعال کنید تمام تنظیمات شما از بین خواهد رفت. با دقت استفاده کنید!',
            )
        );

        $this->license_fields = array(
            $license_version_field, 
            $license_key_field, 
        );

        $this->other_fields = array(
            $tracking_field,
            $purge_field,
        );

        if ( JWP6_USE_CUSTOM_SHORTCODE_FILTER ) {
            $this->shortcode_fields = array(
                $category_config_field,
                $search_config_field,
                $tag_config_field,
                $home_config_field,
            );
        } else {
            $this->shortcode_fields = array();
        }

        $this->form_fields = array_merge(
            $this->license_fields,
            $this->shortcode_fields,
            $this->other_fields
        );

    }

    public function license_key_validation($value) {
        return ( preg_match('/^\S*$/', $value) ) ? $value : NULL;
    }

    public function render() {
        $this->render_page_start('مکان و مجوز');
        $this->render_all_messages();
        ?>
        <form method="post" action="<?php echo $this->page_url(); ?>">
            <?php settings_fields(JWP6 . 'menu_licensing'); ?>

            <h3>تنظیمات مجوز</h3>

            <p>
                به طور پیش فرض این افزونه از نسخه 6 (رایگان) پخش کننده JW استفاده می کند. اگر شما به عنوان یک سایت تجاری فعالیت می کنید، شما نیاز به <a href="<?php echo JWP6_Plugin::$urls['player_pricing']; ?>"> خرید یک کلید مجوز</a> برای پخش کننده JW دارید. علاوه بر برداشتن واترمارک پخش کننده ، یک کلید مجوز این ویژگی ها را باز می کند: ویزگی هایی شبیه یک لوگوی دلخواه، پوسته های ویژه، به اشتراک گذاری فیسبوک و توییتر، یکپارچگی گوگل آنالیز و پشتیبانی جریان HLS اپل.
            </p>

            <table class="form-table">
                <?php foreach ($this->license_fields as $field) { $this->render_form_row($field); } ?>
            </table>

            <div class="divider"></div>


            <?php if ( JWP6_USE_CUSTOM_SHORTCODE_FILTER ): ?>
            <h3>تنظیمات شرت کد</h3>

            <p>
                پیکربندی کنید که آیا شما می خواهید پخش کننده در برگه های بازنگری (برگه اصلی، برچسب ها و ... ) قرار گیرد. بسته به پوسته وردپرس شما، افزونه پخش کننده باید دو شرت کد <code>the_excerpt</code> یا <code>the_content</code> را ارائه دهد. گزینه سوم برای غیرفعال کردن قرار دادن پخش کننده در یک نوع برگه خاص است. این نوار خارج از شرت کد است.
            </p>

            <table class="form-table">
                <?php foreach ($this->shortcode_fields as $field) { $this->render_form_row($field); } ?>
            </table>

            <div class="divider"></div>
            <?php endif; ?>

            <h3>تنظیمات دیگر</h3>

            <table class="form-table">
                <?php if ( is_null(JWP6_PLAYER_LOCATION) ): ?>
                <tr>
                    <th>
                        نسخه پخش کننده
                    </th>
                    <td>
                        <strong> <?php echo JWP6_Plugin::$player_version; ?></strong>
                        <p class="description">
                            پخش کننده خود را به صورت خودکار از طریق بروزرسانی های افزونه های وردپرس، بروزرسانی می کند. فایل های باینری در کانادا توسط Longtail Video میزبانی می شوند. 
                        </p>
                    </td>
                </tr>
                <?php endif; ?>
                <?php foreach ($this->other_fields as $field) { $this->render_form_row($field); } ?>
            </table>

            <p class="submit">
                <input type="submit" name="submit" id="submit" class="button-primary" value="ذخیره ی تغییرات"  />
            </p>
        </form>

        <script type="text/javascript">
            jQuery(function () {
                var $ = jQuery;
                function check_key(e) {
                    var
                        version = $('#license_version').val();
                        key = $('#license_key').val();

                    alert('ما یک نسخه ' + version + ' با یک کلید داریم. ' + key);

                }
                $('#license_version').bind('change', check_key);
            });
        </script>
        <?php
        $this->render_page_end();
    }

}
